:math:`x(n) \longleftrightarrow X(k)`

:math:`x(a n) \longleftrightarrow \frac{X(\frac{k}{a})}{\left|{a}\right|}`

:math:`x(- m + n) \longleftrightarrow X(k) e^{- \frac{2 \mathrm{j} \pi k m}{N}}`

:math:`1 \longleftrightarrow N \delta\left[k\right]`

:math:`\delta\left[n\right] \longleftrightarrow 1`

:math:`\delta\left[- m + n\right] \longleftrightarrow e^{- \frac{2 \mathrm{j} \pi k m}{N}}`

:math:`u\left[n\right] \longleftrightarrow N \delta\left[k\right]`

:math:`n u\left[n\right] \longleftrightarrow \frac{N \left(N - 1\right) \delta\left[k\right]}{2} + \frac{N \left(\delta\left[k\right] - 1\right)}{1 - e^{- \frac{2 \mathrm{j} \pi k}{N}}}`

:math:`\alpha^{- n} u\left[n\right] \longleftrightarrow \frac{\alpha^{- N} \left(- \alpha + \alpha^{N + 1}\right) e^{\frac{2 \mathrm{j} \pi k}{N}}}{\alpha e^{\frac{2 \mathrm{j} \pi k}{N}} - 1}`

:math:`e^{\frac{2 \mathrm{j} \pi n}{N}} \longleftrightarrow N \delta\left[k - 1\right]`

:math:`\cos{\left(\frac{2 \pi n}{N} \right)} \longleftrightarrow \frac{N \left(\delta\left[k - 1\right] + \delta\left[- N + k + 1\right]\right)}{2}`

:math:`\sin{\left(\frac{2 \pi n}{N} \right)} \longleftrightarrow \frac{\mathrm{j} N \left(- \delta\left[k - 1\right] + \delta\left[- N + k + 1\right]\right)}{2}`

